@@ -43,11 +43,14 @@
 #include <colord/cd-dom.h>
 #include <colord/cd-enum.h>
 #include <colord/cd-icc.h>
+#include <colord/cd-icc-store.h>
 #include <colord/cd-interp-akima.h>
 #include <colord/cd-interp-linear.h>
 #include <colord/cd-interp.h>
 #include <colord/cd-it8.h>
 #include <colord/cd-math.h>
+#include <colord/cd-quirk.h>
+#include <colord/cd-transform.h>
 
 #undef __COLORD_H_INSIDE__
 
